##  Linking Diagrams to Other Diagrams in
This feature enables you to manage large and complex architectural diagrams effectively. You can create multiple diagrams with varying levels of detail and link them to navigate across different abstraction layers.
When editing, you can link a diagram directly to a shape through a hyperlink. Clicking the shape opens the linked diagram in a new browser tab.
However, the following conditions should be kept in mind:
  * You can not link a diagram to a shape if the shape is already linked to a fact sheet.
  * You can not link a diagram to a shape that is a 'connector.'
  * Each shape can be linked to only one diagram.


To learn how to link, unlink, and change the linked diagram, see [Linking Diagrams to Other Diagrams in Free Draw](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__linking_diagram_to_other_diagrams).
